import customtkinter as ctk
from tkinter import messagebox, filedialog
import os
from utils.api_requests import create_shop_api  # Import API function


def create_shop_frame(parent, switch_func, API_URL, token):
    frame = ctk.CTkFrame(parent)
    frame.access_token = token

    def update_token(new_token):
        frame.access_token = new_token

    frame.update_token = update_token

    selected_file_path = [None]

    def select_file():
        file_path = filedialog.askopenfilename(title="Select Shop Image")
        if file_path:
            selected_file_path[0] = file_path
            file_label.configure(text=os.path.basename(file_path))
        else:
            selected_file_path[0] = None
            file_label.configure(text="No file selected")

    def create_shop():
        name = entry_name.get()
        description = entry_description.get()

        if not name:
            messagebox.showwarning("Input Error", "Shop name is required!")
            return

        # Call the API function from shop_api.py
        status_code, response_data = create_shop_api(
            name, description, selected_file_path[0], API_URL, frame.access_token
        )

        if status_code == 200:
            messagebox.showinfo("Shop Created", f"Shop '{name}' created successfully!")
        else:
            messagebox.showerror(
                "Error", response_data.get("detail", "An error occurred")
            )

    ctk.CTkLabel(frame, text="Create Shop", font=("Helvetica", 18, "bold")).pack(
        pady=10
    )

    ctk.CTkLabel(frame, text="Shop Name:").pack(pady=5)
    entry_name = ctk.CTkEntry(frame, placeholder_text="Enter shop name")
    entry_name.pack(pady=5)

    ctk.CTkLabel(frame, text="Description:").pack(pady=5)
    entry_description = ctk.CTkEntry(frame, placeholder_text="Enter shop description")
    entry_description.pack(pady=5)

    ctk.CTkButton(frame, text="Select Image", command=select_file).pack(pady=5)
    file_label = ctk.CTkLabel(frame, text="No file selected")
    file_label.pack(pady=5)

    ctk.CTkButton(
        frame, text="Create Shop", fg_color="green", command=create_shop
    ).pack(pady=15)

    ctk.CTkButton(
        frame, text="Back", fg_color="transparent", command=lambda: switch_func("login")
    ).pack(pady=5)

    return frame
